import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Enums/PaddingEnum.dart';
import 'package:flutter_helper/src/Views/BorderView.dart';

class ChildrenUtil {
  List<Widget> getGridAllPaddedChildren(List<Widget> children, {PaddingEnum paddingEnum = PaddingEnum.all, double padding = 12}) {
    final halfPadding = padding / 2;

    for (var i = 0; i < children.length; i++) {
      if (children[i] is SizedBox) {
        children[i] = children[i];
      } else {
        if (i == children.length - 1) {
          children[i] = Padding(
            child: children[i],
            padding: i % 2 == 0
                ? EdgeInsets.only(top: padding, left: padding, right: halfPadding, bottom: padding)
                : EdgeInsets.only(top: padding, left: halfPadding, right: padding, bottom: padding),
          );
        } else {
          children[i] = Padding(
            child: children[i],
            padding: i % 2 == 0
                ? EdgeInsets.only(top: padding, left: padding, right: halfPadding)
                : EdgeInsets.only(top: padding, left: halfPadding, right: padding),
          );
        }
      }
    }

    return children;
  }

  List<Widget> getAllPaddedChildren(List<Widget> children, {double padding = 12, bool isOutside = true}) {
    children.removeWhere((element) => element is SizedBox);

    var paddingEnum;

    if (isOutside) {
      paddingEnum = (i) => i == children.length - 1 ? PaddingEnum.all : PaddingEnum.topHorizontal;
    } else {
      paddingEnum = (i) => i == 0 ? null : PaddingEnum.top;
    }

    for (var i = 0; i < children.length; i++) {
      children[i] = PaddedView(
        child: children[i],
        paddingEnum: paddingEnum(i),
        padding: padding,
      );
    }

    return children;
  }

  List<Widget> getDividedChildren(List<Widget> children) {
    for (var i = 0; i < children.length; i++) {
      children[i] = BorderView(
          child: children[i]
      );
    }

    return children;
  }
}