import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Views/PaginationView.dart';
import 'package:quiver/iterables.dart';

class CustomListRowView extends StatelessWidget {
  final List<Widget> children;
  final double crossAxisCount;
  final Future<void> Function() callback;
  final Function notFoundWidget;
  final bool isGrid;

  CustomListRowView({
    this.children,
    this.crossAxisCount,
    this.callback,
    this.notFoundWidget,
    this.isGrid
  });

  @override
  Widget build(BuildContext context) {
    final paddedChildren = isGrid ? ChildrenUtil().getGridAllPaddedChildren(children) : ChildrenUtil().getAllPaddedChildren(children);

    return PaginationView(child: (scrollController, circularProgressIndicator) {
      return LayoutBuilder(builder: (context, constraints) {
        if (isGrid) {
          if (constraints.maxWidth < 600) {
            return Scrollbar(
                child: notFoundWidget(GridView.count(
                  crossAxisCount: 2,
                  controller: scrollController,
                  children: [...paddedChildren, circularProgressIndicator],
                ))
            );
          } else {
            return Scrollbar(
              child: notFoundWidget(Padding(
                padding: const EdgeInsets.all(8.0),
                child: GridView.count(
                  crossAxisCount: crossAxisCount.toInt(),
                  controller: scrollController,
                  children: [...paddedChildren, circularProgressIndicator],
                ),
              )),
            );
          }
        } else {
          if (constraints.maxWidth < 600) {
            return Scrollbar(
                child: notFoundWidget(ListView(
                  padding: EdgeInsets.zero,
                  controller: scrollController,
                  children: [...paddedChildren, circularProgressIndicator],
                ))
            );
          } else {
            return Scrollbar(
              child: notFoundWidget(ListView(
                padding: EdgeInsets.zero,
                controller: scrollController,
                children: [...[for (final subChildren in partition(paddedChildren, crossAxisCount.toInt())) Row(crossAxisAlignment: CrossAxisAlignment.start, mainAxisAlignment: MainAxisAlignment.center, children: [for (final child in subChildren) child])], circularProgressIndicator],
              )),
            );
          }
        }
      });
    }, callback: callback);
  }
}
